@@ -1,10 +1,10 @@
-"""Conductor User GET route schemas."""
+"""Blackcap User GET route schemas."""
 
 from enum import Enum, unique
 from typing import List, Optional
 
-from conductor.schemas.api.common import ResponseSchema
-from conductor.schemas.user import User
+from blackcap.schemas.api.common import ResponseSchema
+from blackcap.schemas.user import User
 
 from pydantic import BaseModel
 
